import { MomentoLogger, ILeaderboardClient, ILeaderboard } from '@gomomento/sdk-core';
import { LeaderboardClientProps } from './leaderboard-client-props';
/**
 * PREVIEW Momento Leaderboard Client
 * WARNING: the API for this client is not yet stable and may change without notice.
 * Please contact Momento if you would like to try this preview.
 *
 * Leaderboard methods return a response object unique to each request.
 * The response object is resolved to a type-safe object of one of several
 * sub-types. See the documentation for each response type for details.
 */
export declare class PreviewLeaderboardClient implements ILeaderboardClient {
    protected readonly logger: MomentoLogger;
    private readonly dataClient;
    private readonly configuration;
    constructor(props?: LeaderboardClientProps);
    close(): void;
    /**
     * Creates an instance of LeaderboardClient with floating point scores up until 53 bits of precision.
     */
    leaderboard(cacheName: string, leaderboardName: string): ILeaderboard;
}
