import { DeterminewhenToRetryRequestProps, RetryStrategy } from './retry-strategy';
import { MomentoLoggerFactory } from '../../';
export interface NoRetryStrategyProps {
    loggerFactory: MomentoLoggerFactory;
}
export declare class NoRetryStrategy implements RetryStrategy {
    private readonly logger;
    constructor(props: NoRetryStrategyProps);
    determineWhenToRetryRequest(props: DeterminewhenToRetryRequestProps): number | null;
}
