import { Interceptor } from '@grpc/grpc-js';
export declare class Header {
    readonly onceOnlyHeaders: string[];
    readonly name: string;
    readonly value: string;
    /**
     * @param {string} name
     * @param {string} value
     */
    constructor(name: string, value: string);
}
export declare class HeaderInterceptor {
    static createHeadersInterceptor(headers: Header[]): Interceptor;
}
