import { MomentoLogger, MomentoLoggerFactory } from '@gomomento/sdk-core/dist/src/config/logging/momento-logger';
export declare enum DefaultMomentoLoggerLevel {
    TRACE = 5,
    DEBUG = 10,
    INFO = 20,
    WARN = 30,
    ERROR = 40
}
export declare class DefaultMomentoLoggerFactory implements MomentoLoggerFactory {
    private readonly level;
    constructor(level?: DefaultMomentoLoggerLevel);
    getLogger(loggerName: string | any): MomentoLogger;
}
export declare class DefaultMomentoLogger implements MomentoLogger {
    private readonly loggerName;
    private readonly level;
    constructor(loggerName: string | any, level: DefaultMomentoLoggerLevel);
    trace(msg: string, ...args: unknown[]): void;
    debug(msg: string, ...args: unknown[]): void;
    info(msg: string, ...args: unknown[]): void;
    warn(msg: string, ...args: unknown[]): void;
    error(msg: string, ...args: unknown[]): void;
    private outputMessage;
}
