import { DeterminewhenToRetryRequestProps, RetryStrategy } from './retry-strategy';
import { EligibilityStrategy } from './eligibility-strategy';
import { MomentoLoggerFactory } from '../../';
export interface FixedCountRetryStrategyProps {
    loggerFactory: MomentoLoggerFactory;
    maxAttempts: number;
    eligibilityStrategy?: EligibilityStrategy;
}
export declare class FixedCountRetryStrategy implements RetryStrategy {
    private readonly logger;
    private readonly eligibilityStrategy;
    private readonly maxAttempts;
    constructor(props: FixedCountRetryStrategyProps);
    determineWhenToRetryRequest(props: DeterminewhenToRetryRequestProps): number | null;
}
