declare class MomentoErrorCodeMetadataConverter {
    private static readonly momentoErrorCodeToMetadataMap;
    /**
     * Converts a MomentoErrorCode enum value to its corresponding metadata type.
     * @param errorCode - The error code to convert.
     * @returns The corresponding metadata type.
     */
    static convert(errorCode: string): string;
}
export { MomentoErrorCodeMetadataConverter };
