import { Middleware, MiddlewareRequestHandler } from '../../config/middleware/middleware';
import { MomentoLoggerFactory } from '../../';
export declare class InFlightRequestCountMiddleware implements Middleware {
    static numActiveRequests: number;
    private readonly logger;
    constructor(loggerFactory: MomentoLoggerFactory);
    onNewRequest(): MiddlewareRequestHandler;
}
