import { Middleware, MiddlewareRequestHandler } from './middleware';
import { MomentoLoggerFactory } from '../..';
/**
 * This class provides an example of how users can implement a Middleware that
 * requires async calls.
 */
export declare class ExampleAsyncMiddleware implements Middleware {
    private readonly logger;
    constructor(loggerFactory: MomentoLoggerFactory);
    onNewRequest(): MiddlewareRequestHandler;
}
