import { ICacheClient } from '@gomomento/sdk-core';
import { BatchDeleteOptions, BatchDeleteResponse, BatchGetOptions, BatchGetResponse, BatchSetOptions, BatchSetResponse, BatchSetItem, defaultMaxConcurrentRequests, defaultTtlSeconds } from './batch-props';
export { BatchDeleteOptions, BatchDeleteResponse, BatchGetOptions, BatchGetResponse, BatchSetOptions, BatchSetResponse, BatchSetItem, defaultMaxConcurrentRequests, defaultTtlSeconds, };
export declare function batchGet(cacheClient: ICacheClient, cacheName: string, keys: Array<string | Uint8Array>, options?: BatchGetOptions): Promise<BatchGetResponse>;
export declare function batchSet(cacheClient: ICacheClient, cacheName: string, items: Array<BatchSetItem>, options?: BatchSetOptions): Promise<BatchSetResponse>;
export declare function batchDelete(cacheClient: ICacheClient, cacheName: string, keys: Array<string | Uint8Array>, options?: BatchDeleteOptions): Promise<BatchDeleteResponse>;
