export declare function convertSingleKeyRequest(requestType: string, key: Uint8Array): RequestSingleKeyLog;
export interface RequestLog {
    requestType: string;
}
interface RequestSingleKeyLog extends RequestLog {
    key: string;
}
interface RequestToLogInterfaceConverterFn<TRequest, TLog extends RequestLog> {
    (request: TRequest): TLog;
}
export declare const CacheRequestToLogInterfaceConverter: Map<string, RequestToLogInterfaceConverterFn<any, RequestLog>>;
export {};
