import { Configuration } from '../config/configuration';
import { CredentialProvider } from '../';
export interface PingClientProps {
    configuration: Configuration;
    endpoint: string;
    credentialProvider: CredentialProvider;
}
export declare class InternalNodeGrpcPingClient {
    private readonly clientWrapper;
    private readonly interceptors;
    private static readonly REQUEST_TIMEOUT_MS;
    private readonly logger;
    /**
     * @param {PingClientProps} props
     */
    constructor(props: PingClientProps);
    ping(): Promise<void>;
}
