import { MomentoLoggerFactory } from '../../';
import { ExperimentalMetricsMiddleware } from './impl/experimental-metrics-middleware';
/**
 * This middleware enables a periodic task to emit the active request count every second as a JSON
 *
 * See `advanced.ts` in the examples directory for an example of how to set up
 * your {Configuration} to enable this middleware.
 */
export declare class ExperimentalActiveRequestCountLoggingMiddleware extends ExperimentalMetricsMiddleware {
    private isLoggingStarted;
    private readonly metricsLogInterval;
    private intervalId;
    constructor(loggerFactory: MomentoLoggerFactory);
    init(): void;
    private startLogging;
    close(): void;
}
