import { Interceptor } from '@grpc/grpc-js';
import { Middleware, MiddlewareRequestHandlerContext } from '../../config/middleware/middleware';
import { MomentoLoggerFactory } from '../../';
import { cache_client } from '@gomomento/generated-types/dist/cacheclient';
export declare function middlewaresInterceptor(loggerFactory: MomentoLoggerFactory, middlewares: Middleware[], middlewareRequestContext: MiddlewareRequestHandlerContext, grpcClient?: cache_client.ScsClient | null): Interceptor;
