import { MomentoLoggerFactory } from '../../';
import { EligibilityStrategy, EligibleForRetryProps } from './eligibility-strategy';
export declare class DefaultEligibilityStrategy implements EligibilityStrategy {
    private readonly logger;
    constructor(loggerFactory: MomentoLoggerFactory);
    isEligibleForRetry(props: EligibleForRetryProps): boolean;
}
