import { MomentoLogger } from '../../';
import { DetermineWhenToResubscribeProps, SubscriptionRetryEligibilityStrategy, SubscriptionRetryStrategy } from '@gomomento/sdk-core';
export interface TopicSubscriptionRetryStrategyProps {
    logger: MomentoLogger;
    eligibilityStrategy?: SubscriptionRetryEligibilityStrategy;
    retryDelayMillis?: number;
}
export declare class TopicSubscriptionRetryStrategy implements SubscriptionRetryStrategy {
    private readonly logger;
    readonly eligibilityStrategy: SubscriptionRetryEligibilityStrategy;
    readonly retryDelayMillis: number;
    constructor(props: TopicSubscriptionRetryStrategyProps);
    determineWhenToResubscribe(props: DetermineWhenToResubscribeProps): number | null;
}
