import { MomentoLogger } from '../..';
import { EligibleForResubscribeProps, SubscriptionRetryEligibilityStrategy } from '@gomomento/sdk-core';
export declare class TopicSubscriptionRetryEligibilityStrategy implements SubscriptionRetryEligibilityStrategy {
    private readonly logger;
    constructor(logger: MomentoLogger);
    isEligibleForResubscribe(props: EligibleForResubscribeProps): boolean;
}
