import { CreateCache, DeleteCache, ListCaches, CacheFlush, CredentialProvider } from '..';
import { Configuration } from '../config/configuration';
import { ControlCallOptions } from '@gomomento/sdk-core/dist/src/internal/clients';
export interface ControlClientProps {
    configuration: Configuration;
    credentialProvider: CredentialProvider;
}
export declare class CacheControlClient {
    private readonly clientWrapper;
    private readonly interceptors;
    private static readonly REQUEST_TIMEOUT_MS;
    private readonly logger;
    private readonly cacheServiceErrorMapper;
    /**
     * @param {ControlClientProps} props
     */
    constructor(props: ControlClientProps);
    close(): void;
    createCache(name: string, options?: ControlCallOptions): Promise<CreateCache.Response>;
    deleteCache(name: string, options?: ControlCallOptions): Promise<DeleteCache.Response>;
    flushCache(cacheName: string, options?: ControlCallOptions): Promise<CacheFlush.Response>;
    private sendFlushCache;
    listCaches(options?: ControlCallOptions): Promise<ListCaches.Response>;
}
