import { AbstractLeaderboard, ILeaderboard } from '@gomomento/sdk-core/dist/src/internal/clients/leaderboard';
import { ILeaderboardDataClient } from '@gomomento/sdk-core/dist/src/internal/clients/leaderboard/ILeaderboardDataClient';
export declare class Leaderboard extends AbstractLeaderboard implements ILeaderboard {
    constructor(dataClient: ILeaderboardDataClient, cacheName: string, leaderboardName: string);
}
