import { AbstractTopicClient } from '@gomomento/sdk-core/dist/src/internal/clients/pubsub/AbstractTopicClient';
import { TopicClientProps } from './topic-client-props';
/**
 * Momento Topic Client.
 *
 * Publish and subscribe to topics.
 */
export declare class TopicClient extends AbstractTopicClient {
    /**
     * Creates an instance of TopicClient.
     */
    constructor(props?: TopicClientProps);
}
