import { Middleware, MiddlewareRequestHandler } from './middleware';
import { MomentoLoggerFactory } from '../..';
/**
 * This middleware implements per-request logging which can be used for
 * debugging.
 *
 * WARNING: enabling this middleware may have minor performance implications,
 * so enable with caution.
 *
 * In order for this middleware to produce output you will need to have
 * set up your {Configuration} with a {MomentoLoggerFactory} instance that
 * is configured to log at DEBUG level or lower.  See `advanced.ts` in the
 * examples directory for an example of how to set up your {Configuration} to
 * enable this middleware.
 */
export declare class RequestLoggingMiddleware implements Middleware {
    private readonly logger;
    private nextRequestId;
    constructor(loggerFactory?: MomentoLoggerFactory);
    onNewRequest(): MiddlewareRequestHandler;
}
