import { ServiceError } from '@grpc/grpc-js';
import { SdkError } from '../../src';
import { ICacheServiceErrorMapper, ResolveOrRejectErrorOptions } from '@gomomento/sdk-core/dist/src/errors/ICacheServiceErrorMapper';
export declare class CacheServiceErrorMapper implements ICacheServiceErrorMapper<ServiceError> {
    private readonly throwOnErrors;
    constructor(throwOnError: boolean);
    returnOrThrowError<TErrorResponse>(err: Error, errorResponseFactoryFn: (err: SdkError) => TErrorResponse): TErrorResponse;
    resolveOrRejectError(opts: ResolveOrRejectErrorOptions<ServiceError>): void;
    convertError(err: ServiceError | null): SdkError;
}
