import { DeterminewhenToRetryRequestProps, RetryStrategy } from './retry-strategy';
import { EligibilityStrategy } from './eligibility-strategy';
import { MomentoLoggerFactory } from '../..';
export interface FixedTimeoutRetryStrategyProps {
    loggerFactory: MomentoLoggerFactory;
    eligibilityStrategy?: EligibilityStrategy;
    retryDelayIntervalMillis?: number;
    responseDataReceivedTimeoutMillis?: number;
}
export declare class FixedTimeoutRetryStrategy implements RetryStrategy {
    private readonly logger;
    private readonly eligibilityStrategy;
    private readonly retryDelayIntervalMillis;
    readonly responseDataReceivedTimeoutMillis: number;
    constructor(props: FixedTimeoutRetryStrategyProps);
    determineWhenToRetryRequest(props: DeterminewhenToRetryRequestProps): number | null;
}
