import { MomentoLoggerFactory } from '@gomomento/sdk-core';
export interface AuthClientConfigurationProps {
    /**
     * Configures logging verbosity and format
     */
    loggerFactory: MomentoLoggerFactory;
}
/**
 * Configuration options for Momento CacheClient.
 *
 * @export
 * @interface Configuration
 */
export interface AuthConfiguration {
    /**
     * @returns {MomentoLoggerFactory} the current configuration options for logging verbosity and format
     */
    getLoggerFactory(): MomentoLoggerFactory;
}
export declare class AuthClientConfiguration implements AuthConfiguration {
    private readonly loggerFactory;
    constructor(props: AuthClientConfigurationProps);
    getLoggerFactory(): MomentoLoggerFactory;
}
