import { MomentoLoggerFactory } from '@gomomento/sdk-core';
import { TopicClientConfiguration, TopicConfiguration } from './topic-configuration';
export declare const NUM_DEFAULT_STREAM_CLIENTS = 4;
export declare const NUM_DEFAULT_UNARY_CLIENTS = 4;
/**
 * Default config provides defaults suitable for most environments; prioritizes success of publishing and receiving messages.
 * @export
 * @class Default
 */
export declare class Default extends TopicClientConfiguration {
    /**
     * Provides the latest recommended configuration for a default environment.  NOTE: this configuration may
     * change in future releases to take advantage of improvements we identify for default configurations.
     * @param {MomentoLoggerFactory} [loggerFactory=defaultLoggerFactory]
     * @returns {TopicConfiguration}
     */
    static latest(loggerFactory?: MomentoLoggerFactory): TopicConfiguration;
}
/**
 * Default config provides defaults suitable for AWS lambda or similar environments; relaxes timeouts, disables keep-alives
 * to avoid issues with execution environments being frozen and resumed, etc.
 * @export
 * @class Lambda
 */
export declare class Lambda extends TopicClientConfiguration {
    /**
     * Provides the latest recommended configuration for a lambda environment.  NOTE: this configuration may
     * change in future releases to take advantage of improvements we identify for default configurations.
     * @param {MomentoLoggerFactory} [loggerFactory=defaultLoggerFactory]
     * @returns {CacheConfiguration}
     */
    static latest(loggerFactory?: MomentoLoggerFactory): TopicClientConfiguration;
}
