import { MomentoLogger } from '@gomomento/sdk-core';
import { Interceptor } from '@grpc/grpc-js';
export declare function convert(v: string | Uint8Array): Uint8Array;
export declare function getCurrentTimeAsDateObject(): Date;
export declare function createDateObjectFromUnixMillisTimestamp(unixMillisTimestamp: number): Date;
export declare function hasExceededDeadlineRelativeToNow(overallDeadline: Date): boolean;
/**
 * Helper method to handle AbortSignal cancellation for gRPC calls.
 * This centralizes the cancellation logic and ensures consistent behavior.
 * @param abortSignal - The AbortSignal to monitor
 * @param grpcCall - The gRPC call to cancel
 * @param operationName - Name of the operation for logging
 */
export declare function setupAbortSignalHandler(logger: MomentoLogger, abortSignal: AbortSignal | undefined, grpcCall: {
    cancel: () => void;
}, operationName: string): void;
/**
 * Helper method to create interceptors with AbortSignal cancellation support.
 * @param abortSignal - The AbortSignal to monitor
 * @returns Array of interceptors including cancellation if abortSignal is provided
 */
export declare function createInterceptorsWithCancellation(interceptors: Interceptor[], abortSignal?: AbortSignal): Interceptor[];
