import { Interceptor } from '@grpc/grpc-js';
import { RetryStrategy } from '../../config/retry/retry-strategy';
import { MomentoLoggerFactory } from '../../';
export interface RetryInterceptorProps {
    clientName: string;
    loggerFactory: MomentoLoggerFactory;
    overallRequestTimeoutMs: number;
    retryStrategy?: RetryStrategy;
}
export declare class RetryInterceptor {
    static createRetryInterceptor(props: RetryInterceptorProps): Interceptor;
}
